==> nextcloud-app-spreed-1%3A10.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/th.js <==
OC.L10N.register(
    "spreed",
    {
    "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น YYYY-MM-DD",
    "Everyone" : "ทุกคน",
    "None" : "ไม่มี",
    "User" : "User",
    "Disabled" : "ปิดการใช้งาน",
    "Users" : "ผู้ใช้งาน",
    "Name" : "ชื่อ",
    "Language" : "ภาษา",
    "Country" : "ประเทศ",
    "Pending" : "อยู่ระหว่างดำเนินการ",
    "Error" : "ข้อผิดพลาด",
    "Saved" : "บันทึกแล้ว",
    "Copy link" : "คัดลอกลิงค์",
    "Dismiss" : "ยกเลิก",
    "Back" : "ย้อนกลับ",
    "Favorite" : "รายการโปรด",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "กลุ่ม",
    "Settings" : "ตั้งค่า",
    "Password protect" : "ป้องกันด้วยรหัสผ่าน",
    "Close" : "ปิด",
    "Reply" : "ตอบกลับ",
    "Remove" : "ลบออก",
    "Today" : "วันนี้",
    "Yesterday" : "เมื่อวานนี้",
    "Enabled" : "เปิดการใช้งาน",
    "Save" : "บันทึก",
    "Password" : "รหัสผ่าน",
    "Login" : "Login",
    "Nickname" : "ชื่อเล่น",
    "Client ID" : "Client ID",
    "guest" : "ผู้เยี่ยมชม",
    "Add users or groups" : "Add users or groups",
    "Edit" : "แก้ไข",
    "Keyboard shortcuts" : "ปุ่มลัด",
    "Search" : "Search",
    "Share link" : "แชร์ลิงค์",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Grid view" : "มุมมองแบบตาราง Grid",
    "Default" : "ค่าเริ่มต้น",
    "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Android app" : "แอพฯ แอนดรอยด์",
    "iOS app" : "แอพฯ IOS",
    "Copy" : "คัดลอก",
    "Copied!" : "คัดลอกแล้ว",
    "Not supported!" : "ไม่สนับสนุน",
    "Press ⌘-C to copy." : "กด ⌘-C เพื่อคัดลอก",
    "Press Ctrl-C to copy." : "กด Ctrl-C เพื่อคัดลอก",
    "Cancel" : "ยกเลิก",
    "Change password" : "เปลี่ยนรหัสผ่าน",
    "Rename" : "เปลี่ยนชื่อ",
    "Send" : "ส่ง",
    "Share" : "แชร์",
    "Error while sharing" : "เกิดข้อผิดพลาดขณะกำลังแชร์ข้อมูล",
    "Favorited" : "รายการโปรด",
    "Contacts" : "ข้อมูลผู้ติดต่อ"
},
"nplurals=1; plural=0;");

==> nextcloud-app-spreed-1%3A10.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/th.js <==
OC.L10N.register(
    "spreed",
    {
    "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น YYYY-MM-DD",
    "Everyone" : "ทุกคน",
    "None" : "ไม่มี",
    "User" : "User",
    "Disabled" : "ปิดการใช้งาน",
    "Users" : "ผู้ใช้งาน",
    "Name" : "ชื่อ",
    "Language" : "ภาษา",
    "Country" : "ประเทศ",
    "Pending" : "อยู่ระหว่างดำเนินการ",
    "Error" : "ข้อผิดพลาด",
    "Saved" : "บันทึกแล้ว",
    "Copy link" : "คัดลอกลิงค์",
    "Dismiss" : "ยกเลิก",
    "Favorite" : "รายการโปรด",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Loading",
    "Groups" : "กลุ่ม",
    "Settings" : "ตั้งค่า",
    "Password protect" : "ป้องกันด้วยรหัสผ่าน",
    "Back" : "ย้อนกลับ",
    "Close" : "ปิด",
    "Reply" : "ตอบกลับ",
    "Remove" : "ลบออก",
    "Today" : "วันนี้",
    "Yesterday" : "เมื่อวานนี้",
    "Enabled" : "เปิดการใช้งาน",
    "Save" : "บันทึก",
    "Password" : "รหัสผ่าน",
    "Login" : "Login",
    "Nickname" : "ชื่อเล่น",
    "Client ID" : "Client ID",
    "guest" : "ผู้เยี่ยมชม",
    "Add users or groups" : "Add users or groups",
    "Edit" : "แก้ไข",
    "Keyboard shortcuts" : "ปุ่มลัด",
    "Search" : "Search",
    "Share link" : "แชร์ลิงค์",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Grid view" : "มุมมองแบบตาราง Grid",
    "Send" : "ส่ง",
    "Default" : "ค่าเริ่มต้น",
    "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Android app" : "แอพฯ แอนดรอยด์",
    "iOS app" : "แอพฯ IOS",
    "Contacts" : "ข้อมูลผู้ติดต่อ",
    "Cancel" : "ยกเลิก"
},
"nplurals=1; plural=0;");
